@@ -2,18 +2,30 @@ package Devel::Cover::Report::Html_subtle;
 use strict;
 use warnings;
 
-our $VERSION = "0.64";
+our $VERSION = '1.33'; # VERSION
 
-use Devel::Cover::DB 0.64;
-use Devel::Cover::Truth_Table 0.64;
+use Devel::Cover::DB;
+use Devel::Cover::Html_Common "launch";
+use Devel::Cover::Truth_Table;
 
+use Getopt::Long;
 use Template 2.00;
-use CGI;
+use HTML::Entities;
 
 my $Template;
 my %Filenames;
 my %File_exists;
 
+sub get_options {
+    my ($self, $opt) = @_;
+    $opt->{option}{outputfile} = "coverage.html";
+    die "Invalid command line options" unless
+        GetOptions($opt->{option},
+                   qw(
+                       outputfile=s
+                     ));
+}
+
 #-------------------------------------------------------------------------------
 # Subroutine : cvg_class()
 # Purpose    : Determine the CSS class for an element based on its amount of
@@ -64,8 +76,9 @@ sub print_summary {
         my $part = $db->{summary}{$file};
         for my $criterion (@showing) {
             my $pc = exists $part->{$criterion}
-            ? sprintf "%4.1f", $part->{$criterion}{percentage}
-            : "n/a";
+                ? do { my $x = sprintf "%5.2f", $part->{$criterion}{percentage};
+                       chop $x; $x }
+                : "n/a";
 
             if ($pc ne 'n/a') {
                 if ($criterion ne 'time') {
@@ -74,11 +87,9 @@ sub print_summary {
                 if (exists $Filenames{$file}) {
                     if ($criterion eq 'branch') {
                         $vals{$file}{$criterion}{link} = "$Filenames{$file}--branch.html";
-                    }
-                    elsif ($criterion eq 'condition') {
+                    } elsif ($criterion eq 'condition') {
                         $vals{$file}{$criterion}{link} = "$Filenames{$file}--condition.html";
-                    }
-                    elsif ($criterion eq 'subroutine') {
+                    } elsif ($criterion eq 'subroutine') {
                         $vals{$file}{$criterion}{link} = "$Filenames{$file}--subroutine.html";
                     }
                 }
@@ -101,10 +112,10 @@ sub print_summary {
         vals        => \%vals,
     };
 
-    my $html = "$options->{outputdir}/coverage.html";
+    my $html = "$options->{outputdir}/$options->{option}{outputfile}";
     $Template->process("summary", $vars, $html) or die $Template->error();
 
-    print "HTML output sent to $html\n";
+    print "HTML output written to $html\n" unless $options->{silent};
 }
 
 
@@ -152,7 +163,7 @@ sub print_file {
         my %metric = get_metrics($db, $options, $file_data, $.);
         my %line = (
             number  => $.,
-            text    => CGI::escapeHTML($l),
+            text    => encode_entities($l),
             metrics => [],
         );
         $line{text} =~ s/\t/        /g;
@@ -170,25 +181,20 @@ sub print_file {
                     link  => "$Filenames{$file}--branch.html#line$."};
                 }
                 push @{$line{metrics}}, \@p;
-            }
-            elsif ($c eq 'condition') {
+            } elsif ($c eq 'condition') {
                 my @tt = $file_data->condition->truth_table($.);
                 my @p;
-                if (@tt)
-                {
+                if (@tt) {
                     foreach (@tt) {
                         push @p, {text  => sprintf("%.0f", $_->[0]->percentage),
                         class => cvg_class($_->[0]->percentage),
                         link  => "$Filenames{$file}--condition.html#line$."};
                     }
-                }
-                else
-                {
+                } else {
                     push @p, { text => "expression contains > 16 terms: ignored" };
                 }
                 push @{$line{metrics}}, \@p;
-            }
-            elsif ($c eq 'subroutine') {
+            } elsif ($c eq 'subroutine') {
                 my @p;
                 while (my $o = shift @{$metric{$c}}) {
                     push @p, {text  => $o->covered,
@@ -196,8 +202,7 @@ sub print_file {
                     link  => "$Filenames{$file}--subroutine.html#line$."};
                 }
                 push @{$line{metrics}}, \@p;
-            }
-            else {
+            } else {
                 my @p;
                 while (my $o = shift @{$metric{$c}}) {
                     push @p, {text  => ($c =~ /statement|pod|time/) ? $o->covered : $o->percentage,
@@ -256,7 +261,7 @@ sub print_branches {
                 class      => cvg_class($b->percentage),
                 parts      => [{text => 'T', class => $tf[0] ? 'covered' : 'uncovered'},
                 {text => 'F', class => $tf[1] ? 'covered' : 'uncovered'}],
-                text       => CGI::escapeHTML($b->text),
+                text       => encode_entities($b->text),
             };
         }
     }
@@ -296,7 +301,7 @@ sub print_conditions {
                 ref        => "line$location",
                 percentage => sprintf("%.0f", $c->[0]->percentage),
                 class      => cvg_class($c->[0]->percentage),
-                condition  => CGI::escapeHTML($c->[1]),
+                condition  => encode_entities($c->[1]),
                 coverage   => $c->[0]->html,
             };
         }
@@ -324,11 +329,9 @@ sub print_subroutines {
     return unless $subroutines;
 
     my @data;
-    for my $location ($subroutines->items)
-    {
+    for my $location ($subroutines->items) {
         my $l = $subroutines->location($location);
-        for my $sub (@$l)
-        {
+        for my $sub (@$l) {
             push @data, {
                 ref   => "line$location",
                 line  => $location,
@@ -370,7 +373,6 @@ sub report {
     %File_exists = map {$_ => -e} @{$options->{file}};
 
     print_stylesheet($db);
-    print_summary($db, $options);
 
     for my $file (@{$options->{file}}) {
         print_file($db,        $file, $options);
@@ -378,6 +380,7 @@ sub report {
         print_conditions($db,  $file, $options) if $options->{show}{condition};
         print_subroutines($db, $file, $options) if $options->{show}{subroutine};
     }
+    print_summary($db, $options);
 }
 
 1;
@@ -386,7 +389,7 @@ package Devel::Cover::Report::Html_subtle::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = "0.64";
+our $VERSION = '1.33'; # VERSION
 
 use base "Template::Provider";
 
@@ -404,8 +407,8 @@ sub fetch {
 $Templates{html} = <<'EOT';
 <?xml version="1.0" encoding="utf-8"?>
 <!--
-This file was generated by Devel::Cover Version 0.64
-Devel::Cover is copyright 2001-2006, Paul Johnson (pjcj\@cpan.org)
+This file was generated by Devel::Cover Version $VERSION
+Devel::Cover is copyright 2001-2019, Paul Johnson (paul\@pjcj.net)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
@@ -701,14 +704,15 @@ s/^\s+//gm for values %Templates;
 
 =head1 NAME
 
-Devel::Cover::Report::Html_subtle - Backend for HTML reporting of coverage
-statistics
+Devel::Cover::Report::Html_subtle - HTML backend for Devel::Cover
+
+=head1 VERSION
+
+version 1.33
 
 =head1 SYNOPSIS
 
- use Devel::Cover::Report::Html_subtle;
-
- Devel::Cover::Report::Html_subtle->report($db, $options);
+ cover -report html_subtle
 
 =head1 DESCRIPTION
 
@@ -726,13 +730,9 @@ Michael Carman (mjcarman@mchsi.com).
 
 Huh?
 
-=head1 VERSION
-
-Version 0.64 - 10th April 2008
-
 =head1 LICENCE
 
-Copyright 2001-2002, Paul Johnson (pjcj@cpan.org)
+Copyright 2001-2019, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
