@@ -1,4 +1,4 @@
-# Copyright 2004-2015, Paul Johnson (paul@pjcj.net)
+# Copyright 2004-2019, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,17 +10,17 @@ package Devel::Cover::Subroutine;
 use strict;
 use warnings;
 
-our $VERSION = '1.21'; # VERSION
+our $VERSION = '1.33'; # VERSION
 
 use base "Devel::Cover::Criterion";
 
-sub uncoverable { $_[0][2] }
-sub covered     { $_[0][0] }
-sub total       { 1 }
-sub percentage  { $_[0][0] ? 100 : 0 }
+sub uncoverable { $_[0][2]               }
+sub covered     { $_[0][0]               }
+sub total       { 1                      }
+sub percentage  { $_[0][0] ? 100 : 0     }
 sub error       { $_[0][0] xor !$_[0][2] }
-sub name        { $_[0][1] }
-sub criterion   { 'subroutine' }
+sub name        { $_[0][1]               }
+sub criterion   { "subroutine"           }
 
 1
 
@@ -32,7 +32,7 @@ Devel::Cover::Statement - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.21
+version 1.33
 
 =head1 SYNOPSIS
 
@@ -54,7 +54,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2004-2015, Paul Johnson (paul@pjcj.net)
+Copyright 2004-2019, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
